﻿using Hotline.Api.Token;
using Hotline.Caches;
using Hotline.CallCenter.BlackLists;
using Hotline.CallCenter.Devices;
using Hotline.CallCenter.Tels;
using Hotline.Permissions;
using Hotline.Repository.SqlSugar;
using Hotline.Settings;
using Hotline.Share.Dtos.CallCenter;
using Hotline.Share.Dtos.User;
using Hotline.Share.Requests;
using Hotline.Users;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using SqlSugar;
using XF.Domain.Authentications;
using XF.Domain.Exceptions;
namespace Hotline.Api.Controllers;

public class HomeController : BaseController
{
    private readonly ISugarUnitOfWork<HotlineDbContext> _uow;
    private readonly ISessionContext _sessionContext;
    private readonly ISystemAuthorityRepository _systemAuthorityRepository;

    public HomeController(
        ISugarUnitOfWork<HotlineDbContext> uow,
        ISessionContext sessionContext,
        ISystemAuthorityRepository systemAuthorityRepository)
    {
        _uow = uow;
        _sessionContext = sessionContext;
        _systemAuthorityRepository = systemAuthorityRepository;
    }
    
    #region 开放请求接口

    [AllowAnonymous]
    [HttpGet("createdb")]
    public Task CreateDb()
    {
        var db = _uow.Db;
        db.DbMaintenance.CreateDatabase();
        db.CodeFirst.InitTables<SystemMenu, SystemAuthority,SystemButton,SystemOrganize,OrgUser>();
        db.CodeFirst.InitTables<SystemDataAuthority>();

        return Task.CompletedTask;
    }

    #endregion

    #region 菜单权限

    /// <summary>
    /// 获取当前用户所有菜单
    /// </summary>
    /// <returns></returns>
    [AllowAnonymous]
    [HttpGet("get-my-auth-menu")]
    public async Task<IReadOnlyList<SystemMenu>> GetUserAuthorityMenuByToken()
    {
        var roles = _sessionContext.Roles;
        return await _systemAuthorityRepository.GetMyMenu(roles);
    }

    /// <summary>
    /// 获取当前用户所有按钮
    /// </summary>
    /// <returns></returns>
    [AllowAnonymous]
    [HttpGet("get-my-auth-button")]
    public async Task<IReadOnlyList<string>> GetUserAuthorityButtonByToken()
    {
        var roles = _sessionContext.Roles;
        return await _systemAuthorityRepository.GetMyButton(roles);
    }



    #endregion


}